.. _guide_quickstart:

Quickstart
==========
Getting started with the Alert Logic SDK for Python requires a few steps.

Installation
------------
Install the latest alertlogic-sdk-python release via :command:`pip`::

    pip install alertlogic-sdk-python --user --upgrade

You may also install a specific version::

    pip install alertlogic-sdk-python==1.0.0 --user

.. note::

   The latest development version can always be found on
   `GitHub <https://github.com/alertlogic/alertlogic-sdk-python>`_.
